@@ -23,7 +23,11 @@
     INT2PTR(type, SvROK(x) ? SvIV(SvRV(x)) : SvIV(x))
 
 #define XS_STRUCT2OBJ(sv, class, obj) \
-        sv_setref_pv(sv, class, (void *) obj);
+    if (obj == NULL) { \
+        sv_setsv(sv, &PL_sv_undef); \
+    } else { \
+        sv_setref_pv(sv, class, (void *) obj); \
+    }
 
 typedef mecab_t      TextMeCab;
 
